#[derive(FromMap)]Expand description
Implements the functionality for converting entries in a BTreeMap into
attributes and values of a struct. It will consume a tokenized version of
the initial struct declaration, and use code generation to implement the
FromMap trait for instantiating the contents of the struct.